@@ -15,7 +15,11 @@ class LogModeAction : public QObject
     Q_OBJECT
 
 public:
-    enum Category { RootCategory, ServicesCategory, OthersCategory };
+    enum Category {
+        RootCategory,
+        ServicesCategory,
+        OthersCategory
+    };
 
     Q_DECLARE_FLAGS(Categories, Category)
 
